@@ -2,6 +2,6 @@
 
 __author__ = """Jim Vogel"""
 __email__ = "james.vogel@capspire.com"
-__version__ = "0.3.1"
+__version__ = "0.3.2"
 
-from tank_forecaster import decomp, events, forecaster, validation
+# from tank_forecaster.tank_forecaster import decomp, events, forecaster, validation
